pub enum WindowEvent<'a> {
Show 23 variants
Resized(PhysicalSize<u32>),
Moved(PhysicalPosition<i32>),
CloseRequested,
Destroyed,
DroppedFile(PathBuf),
HoveredFile(PathBuf),
HoveredFileCancelled,
ReceivedCharacter(char),
Focused(bool),
KeyboardInput {
device_id: DeviceId,
input: KeyboardInput,
is_synthetic: bool,
},
ModifiersChanged(ModifiersState),
Ime(Ime),
CursorMoved {
device_id: DeviceId,
position: PhysicalPosition<f64>,
modifiers: ModifiersState,
},
CursorEntered {
device_id: DeviceId,
},
CursorLeft {
device_id: DeviceId,
},
MouseWheel {
device_id: DeviceId,
delta: MouseScrollDelta,
phase: TouchPhase,
modifiers: ModifiersState,
},
MouseInput {
device_id: DeviceId,
state: ElementState,
button: MouseButton,
modifiers: ModifiersState,
},
TouchpadPressure {
device_id: DeviceId,
pressure: f32,
stage: i64,
},
AxisMotion {
device_id: DeviceId,
axis: u32,
value: f64,
},
Touch(Touch),
ScaleFactorChanged {
scale_factor: f64,
new_inner_size: &'a mut PhysicalSize<u32>,
},
ThemeChanged(Theme),
Occluded(bool),
}Expand description
Describes an event from a [Window].
Variants
Resized(PhysicalSize<u32>)
The size of the window has changed. Contains the client area’s new dimensions.
Moved(PhysicalPosition<i32>)
The position of the window has changed. Contains the window’s new position.
Platform-specific
- iOS / Android / Web / Wayland: Unsupported.
CloseRequested
The window has been requested to close.
Destroyed
The window has been destroyed.
DroppedFile(PathBuf)
A file has been dropped into the window.
When the user drops multiple files at once, this event will be emitted for each file separately.
HoveredFile(PathBuf)
A file is being hovered over the window.
When the user hovers multiple files at once, this event will be emitted for each file separately.
HoveredFileCancelled
A file was hovered, but has exited the window.
There will be a single HoveredFileCancelled event triggered even if multiple files were
hovered.
ReceivedCharacter(char)
The window received a unicode character.
See also the Ime event for more complex character sequences.
Focused(bool)
The window gained or lost focus.
The parameter is true if the window has gained focus, and false if it has lost focus.
KeyboardInput
An event from the keyboard has been received.
Fields
input: KeyboardInputis_synthetic: boolIf true, the event was generated synthetically by winit
in one of the following circumstances:
- Synthetic key press events are generated for all keys pressed when a window gains focus. Likewise, synthetic key release events are generated for all keys pressed when a window goes out of focus. Currently, this is only functional on X11 and Windows
Otherwise, this value is always false.
ModifiersChanged(ModifiersState)
The keyboard modifiers have changed.
Platform-specific
- Web: This API is currently unimplemented on the web. This isn’t by design - it’s an issue, and it should get fixed - but it’s the current state of the API.
Ime(Ime)
An event from an input method.
Note: You have to explicitly enable this event using [Window::set_ime_allowed].
Platform-specific
- iOS / Android / Web: Unsupported.
CursorMoved
The cursor has moved on the window.
Fields
position: PhysicalPosition<f64>(x,y) coords in pixels relative to the top-left corner of the window. Because the range of this data is limited by the display area and it may have been transformed by the OS to implement effects such as cursor acceleration, it should not be used to implement non-cursor-like interactions such as 3D camera control.
modifiers: ModifiersStateDeprecated in favor of WindowEvent::ModifiersChanged
CursorEntered
The cursor has entered the window.
CursorLeft
The cursor has left the window.
MouseWheel
A mouse wheel movement or touchpad scroll occurred.
Fields
delta: MouseScrollDeltaphase: TouchPhasemodifiers: ModifiersStateDeprecated in favor of WindowEvent::ModifiersChanged
MouseInput
An mouse button press has been received.
Fields
state: ElementStatemodifiers: ModifiersStateDeprecated in favor of WindowEvent::ModifiersChanged
TouchpadPressure
Touchpad pressure event.
At the moment, only supported on Apple forcetouch-capable macbooks. The parameters are: pressure level (value between 0 and 1 representing how hard the touchpad is being pressed) and stage (integer representing the click level).
AxisMotion
Motion on some analog axis. May report data redundant to other, more specific events.
Touch(Touch)
Touch event has been received
ScaleFactorChanged
The window’s scale factor has changed.
The following user actions can cause DPI changes:
- Changing the display’s resolution.
- Changing the display’s scale factor (e.g. in Control Panel on Windows).
- Moving the window to a display with a different scale factor.
After this event callback has been processed, the window will be resized to whatever value
is pointed to by the new_inner_size reference. By default, this will contain the size suggested
by the OS, but it can be changed to any value.
For more information about DPI in general, see the dpi module.
ThemeChanged(Theme)
The system window theme has changed.
Applications might wish to react to this to change the theme of the content of the window when the system changes the window theme.
Platform-specific
At the moment this is only supported on Windows.
Occluded(bool)
The window has been occluded (completely hidden from view).
This is different to window visibility as it depends on whether the window is closed, minimised, set invisible, or fully occluded by another window.
Platform-specific behavior:
- iOS / Android / Web / Wayland / Windows: Unsupported.
Implementations
Sourceimpl<'a> WindowEvent<'a>
impl<'a> WindowEvent<'a>
pub fn to_static(self) -> Option<WindowEvent<'static>>